Path utilities for cross-platform compatibility.
Functions
- ensure_
dir - Ensure a directory exists, creating it if necessary.
- is_dir
- Check if a path exists and is a directory.
- is_file
- Check if a path exists and is a file.
- normalize_
path - Normalize a path for the current platform.
- read_
file - Read a file to string safely.
- write_
file - Write a string to a file safely.